==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QHashSeed_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qhashfunctions.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QHashSeed(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHashSeed")
    QHashSeed *_ptr = reinterpret_cast<QHashSeed *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QHashSeed(size_t)
void __qt_construct_QHashSeed_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHashSeed(size_t)")
    Q_UNUSED(__java_arguments)
    QHashSeed *__qt_this = new(__qtjambi_ptr) QHashSeed();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QHashSeed(size_t)
void __qt_construct_QHashSeed_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHashSeed(size_t)")
    jlong d0 = __java_arguments[0].j;
    Q_UNUSED(d0)
    QHashSeed *__qt_this = new(__qtjambi_ptr) QHashSeed(static_cast<size_t>(d0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QHashSeed
void __qt_destruct_QHashSeed(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHashSeed")
    reinterpret_cast<QHashSeed*>(ptr)->~QHashSeed();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHashSeed::QHashSeed(size_t)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_initialize_1native__Lio_qt_core_QHashSeed_2J)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jlong d0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHashSeed::QHashSeed(size_t)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.j = d0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHashSeed_1, sizeof(QHashSeed), typeid(QHashSeed), false, &deleter_QHashSeed, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHashSeed::operator size_t()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_seed_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QHashSeed *__qt_this = QtJambiAPI::objectFromNativeId<QHashSeed>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHashSeed::operator size_t()const", __qt_this)
        size_t __qt_return_value = *__qt_this;
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHashSeed::globalSeed()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_globalSeed__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHashSeed::globalSeed()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QHashSeed __qt_return_value = QHashSeed::globalSeed();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHashSeed::resetRandomGlobalSeed()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_resetRandomGlobalSeed__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHashSeed::resetRandomGlobalSeed()")
    QTJAMBI_TRY {
        QHashSeed::resetRandomGlobalSeed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHashSeed::setDeterministicGlobalSeed()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_setDeterministicGlobalSeed__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHashSeed::setDeterministicGlobalSeed()")
    QTJAMBI_TRY {
        QHashSeed::setDeterministicGlobalSeed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QHashSeed *__qt_this = QtJambiAPI::objectFromNativeId<QHashSeed>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHashSeed(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QHashSeed>("QHashSeed", "io/qt/core/QHashSeed");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHashSeed, {
        ConstructorInfo(&__qt_construct_QHashSeed_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QHashSeed_1, "J")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHashSeed);
    registerMetaType<QHashSeed>("QHashSeed");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QHashSeed_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qhashfunctions.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QHashSeed(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHashSeed")
    QHashSeed *_ptr = reinterpret_cast<QHashSeed *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QHashSeed(QHashSeed)
void __qt_construct_QHashSeed_cref_QHashSeed(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHashSeed(QHashSeed)")
    jobject other0 = __java_arguments[0].l;
    const QHashSeed& __qt_other0 = qtjambi_cast<const QHashSeed& >(__jni_env, other0);
    QHashSeed *__qt_this = new(__qtjambi_ptr) QHashSeed(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QHashSeed::QHashSeed(QHashSeed)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_initialize_1native__Lio_qt_core_QHashSeed_2Lio_qt_core_QHashSeed_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHashSeed::QHashSeed(QHashSeed)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHashSeed_cref_QHashSeed, sizeof(QHashSeed), typeid(QHashSeed), false, &deleter_QHashSeed, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QHashSeed(size_t)
void __qt_construct_QHashSeed(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHashSeed(size_t)")
    Q_UNUSED(__java_arguments)
    QHashSeed *__qt_this = new(__qtjambi_ptr) QHashSeed();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QHashSeed(size_t)
void __qt_construct_QHashSeed_size_t(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHashSeed(size_t)")
    jlong d0 = __java_arguments[0].j;
    Q_UNUSED(d0)
    QHashSeed *__qt_this = new(__qtjambi_ptr) QHashSeed(static_cast<size_t>(d0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QHashSeed::QHashSeed(size_t)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_initialize_1native__Lio_qt_core_QHashSeed_2J)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jlong d0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHashSeed::QHashSeed(size_t)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.j = d0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHashSeed_size_t, sizeof(QHashSeed), typeid(QHashSeed), false, &deleter_QHashSeed, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QHashSeed
void __qt_destruct_QHashSeed(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHashSeed")
    reinterpret_cast<QHashSeed*>(ptr)->~QHashSeed();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHashSeed::operator size_t()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_seed_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QHashSeed *__qt_this = QtJambiAPI::objectFromNativeId<QHashSeed>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHashSeed::operator size_t()const", __qt_this)
        size_t __qt_return_value = *__qt_this;
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHashSeed::globalSeed()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_globalSeed__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHashSeed::globalSeed()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QHashSeed __qt_return_value = QHashSeed::globalSeed();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHashSeed::resetRandomGlobalSeed()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_resetRandomGlobalSeed__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHashSeed::resetRandomGlobalSeed()")
    QTJAMBI_TRY {
        QHashSeed::resetRandomGlobalSeed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHashSeed::setDeterministicGlobalSeed()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_setDeterministicGlobalSeed__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHashSeed::setDeterministicGlobalSeed()")
    QTJAMBI_TRY {
        QHashSeed::setDeterministicGlobalSeed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QHashSeed_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QHashSeed *__qt_this = QtJambiAPI::objectFromNativeId<QHashSeed>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHashSeed(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QHashSeed>("QHashSeed", "io/qt/core/QHashSeed");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHashSeed, {
        ConstructorInfo(&__qt_construct_QHashSeed_cref_QHashSeed, "Lio/qt/core/QHashSeed;")
       ,ConstructorInfo(&__qt_construct_QHashSeed, nullptr)
       ,ConstructorInfo(&__qt_construct_QHashSeed_size_t, "J")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHashSeed);
    registerMetaType<QHashSeed>("QHashSeed");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
